==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/modules/payment/hpeps.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	hpeps.lang.inc.php 2015-04-29 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
    'MODULE_PAYMENT_HPEPS_TEXT_ERROR' => 'Bei der Zahlungsverarbeitung ist in Fehler aufgetreten.',
	'MODULE_PAYMENT_HPEPS_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_HPEPS_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_HPEPS_CANCELED_STATUS_ID_DESC' => 'Dieser Status wird gesetzt wenn die Bezahlung abgebrochen wurde.',
	'MODULE_PAYMENT_HPEPS_CANCELED_STATUS_ID_TITLE' => 'Bestellstatus - Abbruch',
	'MODULE_PAYMENT_HPEPS_DEBUG_DESC' => 'Schalten Sie diesen nur auf Anweisung von heidelpay an, da sonst eine Bezahlung im Shop nicht mehr funktioniert.',
	'MODULE_PAYMENT_HPEPS_DEBUG_TITLE' => 'Debug Modus',
	'MODULE_PAYMENT_HPEPS_DEBUGTEXT' => 'Das Zahlverfahren wird gerade gewartet. Bitte wählen Sie ein anderes Zahlverfahren oder versuchen Sie es zu einem späteren Zeitpunkt.',
	'MODULE_PAYMENT_HPEPS_DIRECT_MODE_DESC' => 'Wenn Modul Mode auf DIRECT dann wählen Sie hier ob die Zahldaten auf einer Extraseite oder in einer Lightbox eingegeben werden sollen.',
	'MODULE_PAYMENT_HPEPS_DIRECT_MODE_TITLE' => 'Direct Mode',
	'MODULE_PAYMENT_HPEPS_MAX_AMOUNT_DESC' => 'Wählen Sie hier den Maximalbetrag <br>(Bitte in EURO-CENT d.h. 5 EUR = 500 Cent).',
	'MODULE_PAYMENT_HPEPS_MAX_AMOUNT_TITLE' => 'Maximum Betrag',
	'MODULE_PAYMENT_HPEPS_MIN_AMOUNT_DESC' => 'Wählen Sie hier den Mindestbetrag <br>(Bitte in EURO-CENT d.h. 5 EUR = 500 Cent).',
	'MODULE_PAYMENT_HPEPS_MIN_AMOUNT_TITLE' => 'Minimum Betrag',
	'MODULE_PAYMENT_HPEPS_MODULE_MODE_DESC' => 'DIRECT: Die Zahldaten werden auf der Zahlverfahrenauswahl mit REGISTER Funktion erfasst (zzgl. Registrierungsgebuehr). <br>AFTER: Die Zahldaten werden nachgelagert mit DEBIT Funktion erfasst.',
	'MODULE_PAYMENT_HPEPS_MODULE_MODE_TITLE' => 'Modul Mode',
	'MODULE_PAYMENT_HPEPS_NEWORDER_STATUS_ID_DESC' => 'Dieser Status wird zu Beginn der Bezahlung gesetzt.',
	'MODULE_PAYMENT_HPEPS_NEWORDER_STATUS_ID_TITLE' => 'Bestellstatus - Neue Bestellung',
	'MODULE_PAYMENT_HPEPS_PAY_MODE_DESC' => 'Wählen Sie zwischen Debit (DB) und Preauthorisation (PA).',
	'MODULE_PAYMENT_HPEPS_PAY_MODE_TITLE' => 'Payment Mode',
	'MODULE_PAYMENT_HPEPS_PENDING_STATUS_ID_DESC' => 'Dieser Status wird gesetzt wenn die der Kunde auf einem Fremdsystem ist.',
	'MODULE_PAYMENT_HPEPS_PENDING_STATUS_ID_TITLE' => 'Bestellstatus - Wartend',
	'MODULE_PAYMENT_HPEPS_PROCESSED_STATUS_ID_DESC' => 'Dieser Status wird gesetzt wenn die Bezahlung erfolgreich war.',
	'MODULE_PAYMENT_HPEPS_PROCESSED_STATUS_ID_TITLE' => 'Bestellstatus - Erfolgreich',
	'MODULE_PAYMENT_HPEPS_SECURITY_SENDER_DESC' => 'Ihre heidelpay Sender ID',
	'MODULE_PAYMENT_HPEPS_SECURITY_SENDER_TITLE' => 'Sender ID',
	'MODULE_PAYMENT_HPEPS_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_HPEPS_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_HPEPS_STATUS_DESC' => 'Möchten Sie das Modul aktivieren?',
	'MODULE_PAYMENT_HPEPS_STATUS_TITLE' => 'Modul aktivieren',
	'MODULE_PAYMENT_HPEPS_SYSTEM_DESC' => 'Wählen Sie hier das heidelpay System.',
	'MODULE_PAYMENT_HPEPS_SYSTEM_TITLE' => 'System',
	'MODULE_PAYMENT_HPEPS_TEST_ACCOUNT_DESC' => 'Im Sandbox Mode sollen folgende E-Mail-Accounts testen können. (Komma getrennt)',
	'MODULE_PAYMENT_HPEPS_TEST_ACCOUNT_TITLE' => 'Test Account',
	'MODULE_PAYMENT_HPEPS_TEXT_DESC' => 'EPS über heidelpay GmbH',
	'MODULE_PAYMENT_HPEPS_TEXT_INFO' => '',
	'MODULE_PAYMENT_HPEPS_TEXT_TITLE' => 'EPS',
	'MODULE_PAYMENT_HPEPS_TRANSACTION_CHANNEL_DESC' => 'Ihre heidelpay Channel ID',
	'MODULE_PAYMENT_HPEPS_TRANSACTION_CHANNEL_TITLE' => 'Channel ID',
	'MODULE_PAYMENT_HPEPS_TRANSACTION_MODE_DESC' => 'Wählen Sie hier den Transaktionsmodus.',
	'MODULE_PAYMENT_HPEPS_TRANSACTION_MODE_TITLE' => 'Transaction Mode',
	'MODULE_PAYMENT_HPEPS_USER_LOGIN_DESC' => 'Ihr heidelpay User Login',
	'MODULE_PAYMENT_HPEPS_USER_LOGIN_TITLE' => 'User Login',
	'MODULE_PAYMENT_HPEPS_USER_PWD_DESC' => 'Ihr heidelpay User Passwort',
	'MODULE_PAYMENT_HPEPS_USER_PWD_TITLE' => 'User Passwort',
	'MODULE_PAYMENT_HPEPS_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_HPEPS_ZONE_TITLE' => 'Zahlungszone'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/modules/payment/hpeps.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	hpeps.lang.inc.php 2015-04-29 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
    'MODULE_PAYMENT_HPEPS_TEXT_ERROR' => 'Bei der Zahlungsverarbeitung ist in Fehler aufgetreten.',
	'MODULE_PAYMENT_HPEPS_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_HPEPS_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_HPEPS_CANCELED_STATUS_ID_DESC' => 'Dieser Status wird gesetzt wenn die Bezahlung abgebrochen wurde.',
	'MODULE_PAYMENT_HPEPS_CANCELED_STATUS_ID_TITLE' => 'Bestellstatus - Abbruch',
	'MODULE_PAYMENT_HPEPS_DEBUG_DESC' => 'Schalte diesen nur auf Anweisung von heidelpay an, da sonst eine Bezahlung im Shop nicht mehr funktioniert.',
	'MODULE_PAYMENT_HPEPS_DEBUG_TITLE' => 'Debug Modus',
	'MODULE_PAYMENT_HPEPS_DEBUGTEXT' => 'Das Zahlverfahren wird gerade gewartet. Bitte wählen Sie ein anderes Zahlverfahren oder versuchen Sie es zu einem späteren Zeitpunkt.',
	'MODULE_PAYMENT_HPEPS_DIRECT_MODE_DESC' => 'Wenn Modul Mode auf DIRECT dann wählen Sie hier ob die Zahldaten auf einer Extraseite oder in einer Lightbox eingegeben werden sollen.',
	'MODULE_PAYMENT_HPEPS_DIRECT_MODE_TITLE' => 'Direct Mode',
	'MODULE_PAYMENT_HPEPS_MAX_AMOUNT_DESC' => 'Wähle hier den Maximalbetrag <br>(Bitte in EURO-CENT d.h. 5 EUR = 500 Cent).',
	'MODULE_PAYMENT_HPEPS_MAX_AMOUNT_TITLE' => 'Maximum Betrag',
	'MODULE_PAYMENT_HPEPS_MIN_AMOUNT_DESC' => 'Wähle hier den Mindestbetrag <br>(Bitte in EURO-CENT d.h. 5 EUR = 500 Cent).',
	'MODULE_PAYMENT_HPEPS_MIN_AMOUNT_TITLE' => 'Minimum Betrag',
	'MODULE_PAYMENT_HPEPS_MODULE_MODE_DESC' => 'DIRECT: Die Zahldaten werden auf der Zahlverfahrenauswahl mit REGISTER Funktion erfasst (zzgl. Registrierungsgebuehr). <br>AFTER: Die Zahldaten werden nachgelagert mit DEBIT Funktion erfasst.',
	'MODULE_PAYMENT_HPEPS_MODULE_MODE_TITLE' => 'Modul Mode',
	'MODULE_PAYMENT_HPEPS_NEWORDER_STATUS_ID_DESC' => 'Dieser Status wird zu Beginn der Bezahlung gesetzt.',
	'MODULE_PAYMENT_HPEPS_NEWORDER_STATUS_ID_TITLE' => 'Bestellstatus - Neue Bestellung',
	'MODULE_PAYMENT_HPEPS_PAY_MODE_DESC' => 'Wähle zwischen Debit (DB) und Preauthorisation (PA).',
	'MODULE_PAYMENT_HPEPS_PAY_MODE_TITLE' => 'Payment Mode',
	'MODULE_PAYMENT_HPEPS_PENDING_STATUS_ID_DESC' => 'Dieser Status wird gesetzt wenn die der Kunde auf einem Fremdsystem ist.',
	'MODULE_PAYMENT_HPEPS_PENDING_STATUS_ID_TITLE' => 'Bestellstatus - Wartend',
	'MODULE_PAYMENT_HPEPS_PROCESSED_STATUS_ID_DESC' => 'Dieser Status wird gesetzt wenn die Bezahlung erfolgreich war.',
	'MODULE_PAYMENT_HPEPS_PROCESSED_STATUS_ID_TITLE' => 'Bestellstatus - Erfolgreich',
	'MODULE_PAYMENT_HPEPS_SECURITY_SENDER_DESC' => 'Deine heidelpay Sender ID',
	'MODULE_PAYMENT_HPEPS_SECURITY_SENDER_TITLE' => 'Sender ID',
	'MODULE_PAYMENT_HPEPS_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_HPEPS_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_HPEPS_STATUS_DESC' => 'Möchtest du das Modul aktivieren?',
	'MODULE_PAYMENT_HPEPS_STATUS_TITLE' => 'Modul aktivieren',
	'MODULE_PAYMENT_HPEPS_SYSTEM_DESC' => 'Wählen Sie hier das heidelpay System.',
	'MODULE_PAYMENT_HPEPS_SYSTEM_TITLE' => 'System',
	'MODULE_PAYMENT_HPEPS_TEST_ACCOUNT_DESC' => 'Im Sandbox Mode sollen folgende E-Mail-Accounts testen können. (Komma getrennt)',
	'MODULE_PAYMENT_HPEPS_TEST_ACCOUNT_TITLE' => 'Test Account',
	'MODULE_PAYMENT_HPEPS_TEXT_DESC' => 'EPS über heidelpay GmbH',
	'MODULE_PAYMENT_HPEPS_TEXT_INFO' => '',
	'MODULE_PAYMENT_HPEPS_TEXT_TITLE' => 'EPS',
	'MODULE_PAYMENT_HPEPS_TRANSACTION_CHANNEL_DESC' => 'Deine heidelpay Channel ID',
	'MODULE_PAYMENT_HPEPS_TRANSACTION_CHANNEL_TITLE' => 'Channel ID',
	'MODULE_PAYMENT_HPEPS_TRANSACTION_MODE_DESC' => 'Wählen Sie hier den Transaktionsmodus.',
	'MODULE_PAYMENT_HPEPS_TRANSACTION_MODE_TITLE' => 'Transaction Mode',
	'MODULE_PAYMENT_HPEPS_USER_LOGIN_DESC' => 'Dein heidelpay User Login',
	'MODULE_PAYMENT_HPEPS_USER_LOGIN_TITLE' => 'User Login',
	'MODULE_PAYMENT_HPEPS_USER_PWD_DESC' => 'Dein heidelpay User Passwort',
	'MODULE_PAYMENT_HPEPS_USER_PWD_TITLE' => 'User Passwort',
	'MODULE_PAYMENT_HPEPS_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_HPEPS_ZONE_TITLE' => 'Zahlungszone'
);
